@@ -558,7 +558,7 @@ calc_network_catchment <- function(sln,
                                    ),
                                    retainAreaProportion = FALSE,
                                    dissolve = FALSE) {
-  longlat <- ifelse(is.projected(sln@sl) == TRUE, FALSE, TRUE)
+  longlat <- ifelse(sp::is.projected(sln@sl) == TRUE, FALSE, TRUE)
   maximpedance <-
     ifelse(longlat == TRUE, maximpedance / 1000, maximpedance)
 
