@@ -3,7 +3,6 @@ context("Test overline function")
 test_that(
   desc = "overline generates a SpatialLinesDataFrame",
   code = {
-    data("routes_fast", package = "stplanr")
-    rnet <- overline(sldf = routes_fast, attrib = "length")
+    rnet <- overline(sl = routes_fast[2:4,], attrib = "length")
     expect_is(object = rnet, class = "SpatialLinesDataFrame")
-  })
\ No newline at end of file
+  })
